<?php
class Archivos {
    /********** ARCHIVOS **********/
    public static function getRuta(){
        return $_SERVER['DOCUMENT_ROOT'] . '/alumnos/';
    }
    
    public static function existeArchivo($carpeta, $archivo){
        return file_exists(self::getRuta() . $carpeta . '/' . $archivo);
    }
    
    public static function rutaArchivo($carpeta, $archivo){
        return self::getRuta() . $carpeta . '/' . $archivo;
    }
    
    public static function eliminaArchivo($carpeta, $archivo){
        return unlink(self::getRuta() . $carpeta . '/' . $archivo);
    }
    
    public static function agregaArchivo ($archivo, $carpeta, $nombre){
        return move_uploaded_file($archivo, self::getRuta() . $carpeta . '/' . $nombre);
    }
    
    public static function getContenido($carpeta, $archivo){
        return @file_get_contents(self::rutaArchivo($carpeta, $archivo));
    }
    
    public static function guardaArchivo($carpeta, $archivo, $contenido){
        return file_put_contents(self::rutaArchivo($carpeta, $archivo), $contenido);
    }
    
    public static function cargaArchivo($carpeta,$archivo){
        $file = $carpeta . '/' . $archivo;                
        if (self::existeArchivo($carpeta, $archivo))
            $t = filemtime(self::rutaArchivo($carpeta, $archivo));
        if ($t)
            $file .= '?t=' . $t;
        return $file;
    }
    
    /********** CARPETAS **********/
    public static function rutaCarpeta($carpeta){
        return self::getRuta() . $carpeta . '/';
    }
    
    public static function abrirCarpeta($carpeta){
        return opendir(self::getRuta() . $carpeta . '/');
    }
    
    public static function existeCapeta($carpeta){
        return file_exists(self::getRuta() . $carpeta);
    }
    
    public static function creaCarpeta($carpeta) {
        return mkdir(self::getRuta() . $carpeta, 0755, true);
    }
}